/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JavaxInterceptorExcludeClassInterceptorsVisitor.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ejbjar.impl.configurator.visitor.method;

import org.ow2.util.ee.deploy.api.deployable.EJBDeployable;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.AbsAnnotationVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.AnnotationType;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarClassMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarDeployableMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarFieldMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarMethodMetadata;

/**
 * This class manages the handling of &#64;{@link javax.interceptor.ExcludeClassInterceptors}
 * annotation.
 * @param <E> an implementation of EJBDeployable
 * @param <D> an implementation of IEjbJarDeployableMetadata
 * @param <C> an implementation of IEjbJarClassMetadata
 * @param <M> an implementation of IEjbJarMethodMetadata
 * @param <F> an implementation of IEjbJarFieldMetadata
 * @author Florent Benoit
 */
public class JavaxInterceptorExcludeClassInterceptorsVisitor<
    E extends EJBDeployable<E>,
    D extends IEjbJarDeployableMetadata<E, D, C, M, F>,
    C extends IEjbJarClassMetadata<E, D, C, M, F>,
    M extends IEjbJarMethodMetadata<E, D, C, M, F>,
    F extends IEjbJarFieldMetadata<E, D, C, M, F>>
        extends AbsAnnotationVisitor<M> implements AnnotationType {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/interceptor/ExcludeClassInterceptors;";

    /**
     * Constructor.
     * @param methodAnnotationMetadata linked to a method metadata.
     */
    public JavaxInterceptorExcludeClassInterceptorsVisitor(final M methodAnnotationMetadata) {
        super(methodAnnotationMetadata);
    }

    /**
     * Visits the end of the annotation.<br>
     * Creates the object and store it.
     */
    @Override
    public void visitEnd() {
        // set flag on method
        getAnnotationMetadata().setExcludeClassInterceptors(true);

    }

    /**
     * @return type of the annotation (its description)
     */
    public String getType() {
        return TYPE;
    }

}
